#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mueval
version:              0.9.4
visibility:           public
id:                   mueval-0.9.4-AZoanvkvp9u1Wb4E1ekpdH
key:                  mueval-0.9.4-AZoanvkvp9u1Wb4E1ekpdH
license:              BSD-3-Clause
maintainer:           Terence Ng <stoicism03@gmail.com>
author:               Gwern <gwern@gwern.net>
homepage:             https://github.com/TerenceNg03/mueval#readme
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It uses the GHC API to evaluate arbitrary Haskell expressions. Importantly, mueval takes many precautions to defang and avoid \"evil\" code.  It uses resource limits, whitelisted modules and Safe Haskell, special Show instances for IO, threads, processes, and changes of directory to sandbox the Haskell code. . It is, in short, intended to be a standalone version of Lambdabot'\''s famous evaluation functionality. For examples and explanations, please see the README file. . Mueval is POSIX-only.

category:             Development, Language
abi:                  417a2c22f42f1531bbd00dbce207359a
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

hidden-modules:       Paths_mueval
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mueval-0.9.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mueval-0.9.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mueval-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mueval
hs-libraries:         HSmueval-0.9.4-AZoanvkvp9u1Wb4E1ekpdH
depends:
    Cabal-3.10.3.0 QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    filepath-1.4.300.1 hint-0.9.0.8-GXb2Ldn3ZSu8adcI68cGw3 mtl-2.3.1
    process-1.6.19.0 show-0.6-BnXWRAqqq9Z2dPRZh4YRYx
    simple-reflect-0.3.3-4oakyQrAlNmGY0dzqIw5dX unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

